package com.tsiwebserver.service;

import java.util.HashMap;
import java.util.List;

public interface StatisticsService{
	//API
    List<HashMap<String,Object>> getSearchDailyInvoke(String start,String end);
    List<HashMap<String,Object>> getSearchMonthlyInvoke(String start,String end);
    
    //systemResource
    List<HashMap<String,Object>> systemResourceMonthlyData(String start,String end);
    List<HashMap<String,Object>> systemResourceDailyData(String start,String end);
    
    //signalStatusGather
    List<HashMap<String,Object>> signalStatusGatherMonthlyData(String start,String end);
    List<HashMap<String,Object>> signalStatusGatherDailyData(String start,String end);
    
  //signalStatusSend
    List<HashMap<String,Object>> signalStatusSendMonthlyData(String start,String end);
    List<HashMap<String,Object>> signalStatusSendDailyData(String start,String end);
}
